#ifndef H_CDW_WRITE_WIZARD
#define H_CDW_WRITE_WIZARD

#include "main.h"
#include "cdw_task.h"
#include "cdw_disc.h"


cdw_rv_t cdw_write_wizard(cdw_task_t *task, cdw_disc_t *disc);


#endif /* #ifndef H_CDW_WRITE_WIZARD */
